

.. image:: https://github.com/xlcnd/isbnlib-bnf/workflows/tests/badge.svg
    :target: https://github.com/xlcnd/isbnlib-bnf/actions
    :alt: Built Status

.. image:: https://img.shields.io/github/issues/xlcnd/isbnlib-bnf/bug.svg?label=bugs&style=flat
    :target: https://github.com/xlcnd/isbnlib-bnf/labels/bug
    :alt: Bugs

.. image:: https://img.shields.io/pypi/dm/isbnlib-bnf.svg?style=flat
    :target: https://pypi.org/project/isbnlib-bnf/
    :alt: PYPI Downloads



A metadata plugin for ``isbnlib`` (https://pypi.python.org/pypi/isbnlib) using the service BnF Catalogue Général (for books in french).

After install, a new metadata provider (``bnf``) is available in isbnlib.

For available plugins check_ here.


.. _check: https://pypi.python.org/pypi?%3Aaction=search&term=isbnlib_&submit=search





